@@ -1,5 +1,5 @@
 translogEst <- function( yName, xNames, data, shifterNames = NULL,
-   quadHalf = TRUE, dataLogged = FALSE, ... ) {
+   dataLogged = FALSE, ... ) {
 
    checkNames( c( yName, xNames, shifterNames ), names( data ) )
 
@@ -11,7 +11,7 @@ translogEst <- function( yName, xNames, data, shifterNames = NULL,
    }
 
    result <- quadFuncEst( yName = yName, xNames = xNames, data = logData,
-      shifterNames = shifterNames, quadHalf = quadHalf, ... )
+      shifterNames = shifterNames, ... )
 
    result$r2nonLog <- rSquared( exp( logData[[ yName ]] ),
       exp( logData[[ yName ]] ) - exp( result$fitted ) )
@@ -24,7 +24,6 @@ translogEst <- function( yName, xNames, data, shifterNames = NULL,
    result$yName         <- yName
    result$xNames        <- xNames
    result$shifterNames  <- shifterNames
-   result$quadHalf      <- quadHalf
    result$dataLogged    <- dataLogged
    result$homWeights    <- NULL
    result$regScale      <- NULL
